@@ -44,12 +44,6 @@ require './regen/embed_lib.pl';
 
 my %docs;
 my %funcflags;
-my %macro = (
-             ax => 1,
-             items => 1,
-             ix => 1,
-             svtype => 1,
-            );
 my %missing;
 
 my $curheader = "Unknown section";
@@ -63,16 +57,11 @@ sub autodoc ($$) { # parse a file and extract documentation info
 
 FUNC:
     while (defined($in = $get_next_line->())) {
-        if ($in =~ /^#\s*define\s+([A-Za-z_][A-Za-z_0-9]+)\(/ &&
-            ($file ne 'embed.h' || $file ne 'proto.h')) {
-            $macro{$1} = $file;
-            next FUNC;
-        }
         if ($in=~ /^=head1 (.*)/) {
             $curheader = $1;
 
             # If the next non-space line begins with a word char, then it is
-            # the start of heading-ldevel documentation.
+            # the start of heading-level documentation.
             if (defined($doc = $get_next_line->())) {
                 # Skip over empty lines
                 while ($doc =~ /^\s+$/) {
@@ -143,9 +132,12 @@ DOC:
                 warn "embed.fnc entry overrides redundant information in"
                    . " '$proto_in_file' in $file" if $flags || $ret || @args;
                 $flags = $embed_docref->{'flags'};
+                warn "embed.fnc entry '$name' missing 'd' flag"
+                                                            unless $flags =~ /d/;
                 $ret = $embed_docref->{'retval'};
                 @args = @{$embed_docref->{args}};
-            } else {
+            } elsif ($flags !~ /m/)  { # Not in embed.fnc, is missing if not a
+                                       # macro
                 $missing{$name} = $file;
             }
 
@@ -369,11 +361,6 @@ for (sort keys %funcflags) {
 }
 
 foreach (sort keys %missing) {
-    next if $macro{$_};
-    # Heuristics for known not-a-function macros:
-    next if /^[A-Z]/;
-    next if /^dj?[A-Z]/;
-
     warn "Function '$_', documented in $missing{$_}, not listed in embed.fnc";
 }
 
